changeset 2891:75a99b4f1c98

Rebranded C++ part from C1X to Graal.
author Thomas Wuerthinger <thomas@wuerthinger.net>
date Wed, 08 Jun 2011 14:01:51 +0200
parents c23d45daff9b
children 5005a5607506
files rundacapo.sh runtests.sh src/cpu/x86/vm/c1_Runtime1_x86.cpp src/cpu/x86/vm/sharedRuntime_x86_64.cpp src/share/vm/c1/c1_Compiler.cpp src/share/vm/c1/c1_Runtime1.cpp src/share/vm/c1/c1_Runtime1.hpp src/share/vm/c1/c1_globals.hpp src/share/vm/ci/ciInstanceKlass.cpp src/share/vm/ci/ciObject.cpp src/share/vm/classfile/systemDictionary.hpp src/share/vm/classfile/vmSymbols.hpp src/share/vm/code/codeBlob.hpp src/share/vm/code/compiledIC.cpp src/share/vm/code/nmethod.cpp src/share/vm/code/nmethod.hpp src/share/vm/compiler/compileBroker.cpp src/share/vm/compiler/compileBroker.hpp src/share/vm/graal/graalCodeInstaller.cpp src/share/vm/graal/graalCompiler.cpp src/share/vm/graal/graalCompiler.hpp src/share/vm/graal/graalJavaAccess.cpp src/share/vm/graal/graalJavaAccess.hpp src/share/vm/graal/graalVMEntries.cpp src/share/vm/graal/graalVMExits.cpp src/share/vm/graal/graalVmIds.cpp src/share/vm/interpreter/rewriter.cpp src/share/vm/oops/klass.cpp src/share/vm/oops/klass.hpp src/share/vm/oops/klassKlass.cpp src/share/vm/prims/jni.cpp src/share/vm/runtime/arguments.cpp src/share/vm/runtime/arguments.hpp src/share/vm/runtime/sharedRuntime.cpp src/share/vm/runtime/thread.hpp
diffstat 35 files changed, 285 insertions(+), 285 deletions(-) [+]
line wrap: on
line diff
--- a/rundacapo.sh	Wed Jun 08 13:40:25 2011 +0200
+++ b/rundacapo.sh	Wed Jun 08 14:01:51 2011 +0200
@@ -15,4 +15,4 @@
   echo "DACAPO is not defined. It must point to a Dacapo benchmark directory."
   exit 1;
 fi
-${JDK7}/bin/java -client -d64 -graal -XX:-C1XBailoutIsFatal -XX:+PrintCompilation -C1X:-QuietBailout -Xms1g -Xmx2g -esa -classpath ${DACAPO}/dacapo-9.12-bach.jar Harness --preserve $*
+${JDK7}/bin/java -client -d64 -graal -XX:-GraalBailoutIsFatal -XX:+PrintCompilation -Xms1g -Xmx2g -esa -classpath ${DACAPO}/dacapo-9.12-bach.jar Harness --preserve $*
--- a/runtests.sh	Wed Jun 08 13:40:25 2011 +0200
+++ b/runtests.sh	Wed Jun 08 14:01:51 2011 +0200
@@ -12,4 +12,4 @@
   exit 1;
 fi
 TESTDIR=${MAXINE}/com.oracle.max.vm/test
-${JDK7}/bin/java -client -d64 -graal -ea -esa -Xcomp -C1X:PrintIdealGraphLevel=0 -C1X:PrintFilter=anewarray -C1X:-PrintCFGToFile -C1X:-PrintAssembly -XX:-TraceSignals -XX:-TraceDeoptimization -XX:-TraceExceptions -XX:+PrintCompilation -XX:CompileOnly=jtt -Xbootclasspath/p:"${MAXINE}/com.oracle.max.vm/bin" -Xbootclasspath/p:"${MAXINE}/com.oracle.max.base/bin" $1 test.com.sun.max.vm.compiler.JavaTester -verbose=1 -gen-run-scheme=false -run-scheme-package=all ${TESTDIR}/jtt/bytecode ${TESTDIR}/jtt/except ${TESTDIR}/jtt/hotpath ${TESTDIR}/jtt/jdk ${TESTDIR}/jtt/lang ${TESTDIR}/jtt/loop ${TESTDIR}/jtt/micro ${TESTDIR}/jtt/optimize ${TESTDIR}/jtt/reflect ${TESTDIR}/jtt/threads
+${JDK7}/bin/java -client -d64 -graal -ea -esa -Xcomp -XX:+PrintCompilation -XX:CompileOnly=jtt -Xbootclasspath/p:"${MAXINE}/com.oracle.max.vm/bin" -Xbootclasspath/p:"${MAXINE}/com.oracle.max.base/bin" $1 test.com.sun.max.vm.compiler.JavaTester -verbose=1 -gen-run-scheme=false -run-scheme-package=all ${TESTDIR}/jtt/bytecode ${TESTDIR}/jtt/except ${TESTDIR}/jtt/hotpath ${TESTDIR}/jtt/jdk ${TESTDIR}/jtt/lang ${TESTDIR}/jtt/loop ${TESTDIR}/jtt/micro ${TESTDIR}/jtt/optimize ${TESTDIR}/jtt/reflect ${TESTDIR}/jtt/threads
--- a/src/cpu/x86/vm/sharedRuntime_x86_64.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/cpu/x86/vm/sharedRuntime_x86_64.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -2650,7 +2650,7 @@
   __ bind(no_pending_exception);
 #endif
 
-  // (tw) Start of C1X uncommon trap code.
+  // (tw) Start of graal uncommon trap code.
   __ jmp(cont);
 
   int jmp_uncommon_trap_offset = __ pc() - start;
@@ -2685,7 +2685,7 @@
   __ jmp(after_fetch_unroll_info_call);
 
 
-  // (tw) End of C1X uncommon trap code.
+  // (tw) End of graal uncommon trap code.
 
   __ bind(cont);
 
--- a/src/share/vm/c1/c1_Compiler.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/c1/c1_Compiler.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -90,7 +90,7 @@
 
 
 void Compiler::compile_method(ciEnv* env, ciMethod* method, int entry_bci) {
-  assert(!UseC1X, "c1 called in UseC1X mode!");
+  assert(!UseGraal, "c1 called in UseGraal mode!");
   // Allocate buffer blob once at startup since allocation for each
   // compilation seems to be too expensive (at least on Intel win32).
   BufferBlob* buffer_blob = CompilerThread::current()->get_buffer_blob();
--- a/src/share/vm/c1/c1_Runtime1.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/c1/c1_Runtime1.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -201,11 +201,11 @@
     case slow_subtype_check_id:
     case fpu2long_stub_id:
     case unwind_exception_id:
-    case c1x_verify_pointer_id:
-    case c1x_unwind_exception_call_id:
-    case c1x_slow_subtype_check_id:
-    case c1x_arithmetic_frem_id:
-    case c1x_arithmetic_drem_id:
+    case graal_verify_pointer_id:
+    case graal_unwind_exception_call_id:
+    case graal_slow_subtype_check_id:
+    case graal_arithmetic_frem_id:
+    case graal_arithmetic_drem_id:
 #ifndef TIERED
     case counter_overflow_id: // Not generated outside the tiered world
 #endif
@@ -468,7 +468,7 @@
   thread->set_is_method_handle_return(false);
 
   Handle exception(thread, ex);
-  if (UseC1X && exception.is_null()) {
+  if (UseGraal && exception.is_null()) {
     exception = Exceptions::new_exception(thread, vmSymbols::java_lang_NullPointerException(), NULL);
   }
   nm = CodeCache::find_nmethod(pc);
@@ -661,7 +661,7 @@
 JRT_ENTRY_NO_ASYNC(void, Runtime1::monitorenter(JavaThread* thread, oopDesc* obj, BasicObjectLock* lock))
   NOT_PRODUCT(_monitorenter_slowcase_cnt++;)
 #ifdef ASSERT
-  if (TraceC1X >= 3) {
+  if (Tracegraal >= 3) {
     tty->print_cr("entered locking slow case with obj=" INTPTR_FORMAT " and lock= " INTPTR_FORMAT, obj, lock);
   }
   if (PrintBiasedLockingStatistics) {
@@ -689,7 +689,7 @@
     }
   }
 #ifdef ASSERT
-  if (TraceC1X >= 3) {
+  if (Tracegraal >= 3) {
     tty->print_cr("exiting locking lock state: obj=" INTPTR_FORMAT, lock->obj());
     lock->lock()->print_on(tty);
     tty->print_cr("");
--- a/src/share/vm/c1/c1_Runtime1.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/c1/c1_Runtime1.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -70,14 +70,14 @@
   stub(g1_post_barrier_slow)         \
   stub(fpu2long_stub)                \
   stub(counter_overflow)             \
-  stub(c1x_unwind_exception_call)    \
-  stub(c1x_handle_exception)         \
-  stub(c1x_slow_subtype_check)       \
-  stub(c1x_arithmetic_frem)          \
-  stub(c1x_arithmetic_drem)          \
-  stub(c1x_monitorenter)             \
-  stub(c1x_monitorexit)              \
-  stub(c1x_verify_pointer)           \
+  stub(graal_unwind_exception_call)    \
+  stub(graal_handle_exception)         \
+  stub(graal_slow_subtype_check)       \
+  stub(graal_arithmetic_frem)          \
+  stub(graal_arithmetic_drem)          \
+  stub(graal_monitorenter)             \
+  stub(graal_monitorexit)              \
+  stub(graal_verify_pointer)           \
   last_entry(number_of_ids)
 
 #define DECLARE_STUB_ID(x)       x ## _id ,
@@ -133,7 +133,7 @@
   static OopMapSet* generate_exception_throw(StubAssembler* sasm, address target, bool has_argument);
   static OopMapSet* generate_handle_exception(StubID id, StubAssembler* sasm);
   static void       generate_unwind_exception(StubAssembler *sasm);
-  static void       c1x_generate_handle_exception(StubAssembler *sasm, OopMapSet* oop_maps, OopMap* oop_map);
+  static void       graal_generate_handle_exception(StubAssembler *sasm, OopMapSet* oop_maps, OopMap* oop_map);
   static OopMapSet* generate_patching(StubAssembler* sasm, address target);
 
   static OopMapSet* generate_stub_call(StubAssembler* sasm, Register result, address entry,
--- a/src/share/vm/c1/c1_globals.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/c1/c1_globals.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -53,14 +53,14 @@
 //
 #define C1_FLAGS(develop, develop_pd, product, product_pd, notproduct)      \
                                                                             \
-  product(bool, UseC1X, false,                                              \
-          "Use C1X instead of C1")                                          \
-  product(bool, C1XBailoutIsFatal, true,                                    \
-          "Abort the VM on C1X bailout")                                    \
-  product(bool, BootstrapC1X, false,                                        \
-          "Bootstrap C1X before running Java main method")                  \
-  product(intx, TraceC1X, 0,                                                \
-          "Trace level for C1X")                                            \
+  product(bool, UseGraal, false,                                              \
+          "Use graal instead of C1")                                          \
+  product(bool, GraalBailoutIsFatal, true,                                    \
+          "Abort the VM on graal bailout")                                    \
+  product(bool, Bootstrapgraal, false,                                        \
+          "Bootstrap graal before running Java main method")                  \
+  product(intx, Tracegraal, 0,                                                \
+          "Trace level for graal")                                            \
   product(bool, TraceSignals, false,                                        \
           "Trace signals and implicit exception handling")                  \
   /* Printing */                                                            \
--- a/src/share/vm/ci/ciInstanceKlass.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/ci/ciInstanceKlass.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -64,7 +64,7 @@
   }
 
   Thread *thread = Thread::current();
-  if (ciObjectFactory::is_initialized() && !UseC1X) {
+  if (ciObjectFactory::is_initialized() && !UseGraal) {
     _loader = JNIHandles::make_local(thread, ik->class_loader());
     _protection_domain = JNIHandles::make_local(thread, ik->protection_domain());
     _is_shared = false;
--- a/src/share/vm/ci/ciObject.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/ci/ciObject.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -52,7 +52,7 @@
 ciObject::ciObject(oop o) {
   ASSERT_IN_VM;
   if (ciObjectFactory::is_initialized()) {
-    if (UseC1X) {
+    if (UseGraal) {
       _handle = JNIHandles::make_global(o);
       _temp_global = true;
     } else {
@@ -73,7 +73,7 @@
 ciObject::ciObject(Handle h) {
   ASSERT_IN_VM;
   if (ciObjectFactory::is_initialized()) {
-    if (UseC1X) {
+    if (UseGraal) {
       _handle = JNIHandles::make_global(h);
       _temp_global = true;
     } else {
--- a/src/share/vm/classfile/systemDictionary.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/classfile/systemDictionary.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -182,14 +182,14 @@
   template(Integer_klass,                java_lang_Integer,              Pre) \
   template(Long_klass,                   java_lang_Long,                 Pre) \
                                                                               \
-  template(C1XOptions_klass,             com_sun_c1x_C1XOptions,                                    Opt) \
-  template(HotSpotTypeResolved_klass,    com_sun_hotspot_c1x_HotSpotTypeResolved,                   Opt) \
-  template(HotSpotType_klass,            com_sun_hotspot_c1x_HotSpotType,                           Opt) \
-  template(HotSpotField_klass,           com_sun_hotspot_c1x_HotSpotField,                          Opt) \
-  template(HotSpotMethodResolved_klass,  com_sun_hotspot_c1x_HotSpotMethodResolved,                 Opt) \
-  template(HotSpotTargetMethod_klass,    com_sun_hotspot_c1x_HotSpotTargetMethod,                   Opt) \
-  template(HotSpotExceptionHandler_klass,com_sun_hotspot_c1x_HotSpotExceptionHandler,               Opt) \
-  template(HotSpotProxy_klass,           com_sun_hotspot_c1x_HotSpotProxy,                          Opt) \
+  template(graalOptions_klass,             com_sun_graal_graalOptions,                                    Opt) \
+  template(HotSpotTypeResolved_klass,    com_sun_hotspot_graal_HotSpotTypeResolved,                   Opt) \
+  template(HotSpotType_klass,            com_sun_hotspot_graal_HotSpotType,                           Opt) \
+  template(HotSpotField_klass,           com_sun_hotspot_graal_HotSpotField,                          Opt) \
+  template(HotSpotMethodResolved_klass,  com_sun_hotspot_graal_HotSpotMethodResolved,                 Opt) \
+  template(HotSpotTargetMethod_klass,    com_sun_hotspot_graal_HotSpotTargetMethod,                   Opt) \
+  template(HotSpotExceptionHandler_klass,com_sun_hotspot_graal_HotSpotExceptionHandler,               Opt) \
+  template(HotSpotProxy_klass,           com_sun_hotspot_graal_HotSpotProxy,                          Opt) \
   template(CiAssumptions_klass,          com_sun_cri_ci_CiAssumptions,                              Opt) \
   template(CiAssumptions_ConcreteSubtype_klass, com_sun_cri_ci_CiAssumptions_ConcreteSubtype,       Opt) \
   template(CiAssumptions_ConcreteMethod_klass,  com_sun_cri_ci_CiAssumptions_ConcreteMethod,        Opt) \
--- a/src/share/vm/classfile/vmSymbols.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/classfile/vmSymbols.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -257,19 +257,19 @@
   NOT_LP64(  do_alias(machine_word_signature,         int_signature)  )                           \
   LP64_ONLY( do_alias(machine_word_signature,         long_signature) )                           \
                                                                                                                         \
-  /* support for C1X */                                                                                                 \
-  template(com_sun_hotspot_c1x_VMExits,               "com/oracle/max/graal/runtime/VMExits")                               \
-  template(com_sun_hotspot_c1x_HotSpotMethodResolved, "com/oracle/max/graal/runtime/HotSpotMethodResolved")                 \
-  template(com_sun_hotspot_c1x_HotSpotTargetMethod,   "com/oracle/max/graal/runtime/HotSpotTargetMethod")                   \
-  template(com_sun_hotspot_c1x_HotSpotField,          "com/oracle/max/graal/runtime/HotSpotField")                          \
-  template(com_sun_c1x_C1XOptions,                    "com/sun/c1x/C1XOptions")                                         \
-  template(com_sun_hotspot_c1x_HotSpotOptions,        "com/oracle/max/graal/runtime/HotSpotOptions")                        \
-  template(com_sun_hotspot_c1x_HotSpotTypeResolved,   "com/oracle/max/graal/runtime/HotSpotTypeResolvedImpl")               \
-  template(com_sun_hotspot_c1x_HotSpotType,           "com/oracle/max/graal/runtime/HotSpotType")                           \
-  template(com_sun_hotspot_c1x_HotSpotExceptionHandler,"com/oracle/max/graal/runtime/HotSpotExceptionHandler")              \
-  template(com_sun_hotspot_c1x_HotSpotProxy,          "com/oracle/max/graal/runtime/HotSpotProxy")                          \
-  template(com_sun_hotspot_c1x_Compiler,              "com/oracle/max/graal/runtime/Compiler")                              \
-  template(com_sun_hotspot_c1x_CompilerImpl,          "com/oracle/max/graal/runtime/CompilerImpl")                          \
+  /* support for graal */                                                                                                 \
+  template(com_sun_hotspot_graal_VMExits,               "com/oracle/max/graal/runtime/VMExits")                               \
+  template(com_sun_hotspot_graal_HotSpotMethodResolved, "com/oracle/max/graal/runtime/HotSpotMethodResolved")                 \
+  template(com_sun_hotspot_graal_HotSpotTargetMethod,   "com/oracle/max/graal/runtime/HotSpotTargetMethod")                   \
+  template(com_sun_hotspot_graal_HotSpotField,          "com/oracle/max/graal/runtime/HotSpotField")                          \
+  template(com_sun_graal_graalOptions,                    "com/sun/graal/graalOptions")                                         \
+  template(com_sun_hotspot_graal_HotSpotOptions,        "com/oracle/max/graal/runtime/HotSpotOptions")                        \
+  template(com_sun_hotspot_graal_HotSpotTypeResolved,   "com/oracle/max/graal/runtime/HotSpotTypeResolvedImpl")               \
+  template(com_sun_hotspot_graal_HotSpotType,           "com/oracle/max/graal/runtime/HotSpotType")                           \
+  template(com_sun_hotspot_graal_HotSpotExceptionHandler,"com/oracle/max/graal/runtime/HotSpotExceptionHandler")              \
+  template(com_sun_hotspot_graal_HotSpotProxy,          "com/oracle/max/graal/runtime/HotSpotProxy")                          \
+  template(com_sun_hotspot_graal_Compiler,              "com/oracle/max/graal/runtime/Compiler")                              \
+  template(com_sun_hotspot_graal_CompilerImpl,          "com/oracle/max/graal/runtime/CompilerImpl")                          \
   template(com_sun_cri_ri_RiMethod,                   "com/sun/cri/ri/RiMethod")                                        \
   template(com_sun_cri_ri_RiField,                    "com/sun/cri/ri/RiField")                                         \
   template(com_sun_cri_ri_RiType,                     "com/sun/cri/ri/RiType")                                          \
--- a/src/share/vm/code/codeBlob.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/code/codeBlob.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -352,7 +352,7 @@
 
   int _unpack_with_exception_in_tls;
 
-  // (tw) Offset when C1X calls uncommon_trap.
+  // (tw) Offset when graal calls uncommon_trap.
   int _uncommon_trap_offset;
   int _jmp_uncommon_trap_offset;
 
@@ -413,7 +413,7 @@
   }
   address unpack_with_exception_in_tls() const   { return code_begin() + _unpack_with_exception_in_tls; }
 
-  // (tw) Offset when C1X calls uncommon_trap.
+  // (tw) Offset when graal calls uncommon_trap.
   void set_uncommon_trap_offset(int offset) {
     _uncommon_trap_offset = offset;
     assert(contains(code_begin() + _uncommon_trap_offset), "must be PC inside codeblob");
--- a/src/share/vm/code/compiledIC.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/code/compiledIC.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -529,7 +529,7 @@
   NativeJump*        jump          = nativeJump_at(method_holder->next_instruction_address());
 
   assert(method_holder->data()    == 0           || method_holder->data()    == (intptr_t)callee(), "a) MT-unsafe modification of inline cache");
-  assert(UseC1X || jump->jump_destination() == (address)-1 || jump->jump_destination() == entry, "b) MT-unsafe modification of inline cache");
+  assert(UseGraal || jump->jump_destination() == (address)-1 || jump->jump_destination() == entry, "b) MT-unsafe modification of inline cache");
 
   // Update stub
   method_holder->set_data((intptr_t)callee());
--- a/src/share/vm/compiler/compileBroker.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/compiler/compileBroker.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -402,7 +402,7 @@
 
   static void print_compiler_threads_on(outputStream* st);
 
-  static void bootstrap_c1x();
+  static void bootstrap_graal();
 };
 
 #endif // SHARE_VM_COMPILER_COMPILEBROKER_HPP
--- a/src/share/vm/graal/graalCompiler.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalCompiler.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -22,28 +22,28 @@
  */
 
 #include "precompiled.hpp"
-#include "c1x/c1x_Compiler.hpp"
-#include "c1x/c1x_JavaAccess.hpp"
-#include "c1x/c1x_VMExits.hpp"
-#include "c1x/c1x_VMEntries.hpp"
-#include "c1x/c1x_VmIds.hpp"
+#include "graal/graalCompiler.hpp"
+#include "graal/graalJavaAccess.hpp"
+#include "graal/graalVMExits.hpp"
+#include "graal/graalVMEntries.hpp"
+#include "graal/graalVmIds.hpp"
 #include "c1/c1_Runtime1.hpp"
 #include "runtime/arguments.hpp"
 
-C1XCompiler* C1XCompiler::_instance = NULL;
+GraalCompiler* GraalCompiler::_instance = NULL;
 
-C1XCompiler::C1XCompiler() {
+GraalCompiler::GraalCompiler() {
   _initialized = false;
   assert(_instance == NULL, "only one instance allowed");
   _instance = this;
 }
 
 // Initialization
-void C1XCompiler::initialize() {
+void GraalCompiler::initialize() {
   if (_initialized) return;
   CompilerThread* THREAD = CompilerThread::current();
   _initialized = true;
-  TRACE_C1X_1("C1XCompiler::initialize");
+  TRACE_graal_1("GraalCompiler::initialize");
 
   VmIds::initializeObjects();
 
@@ -53,7 +53,7 @@
   JNIEnv *env = ((JavaThread *) Thread::current())->jni_environment();
   jclass klass = env->FindClass("com/oracle/max/graal/runtime/VMEntriesNative");
   if (klass == NULL) {
-    tty->print_cr("c1x VMEntries class not found");
+    tty->print_cr("graal VMEntries class not found");
     vm_abort(false);
   }
   env->RegisterNatives(klass, VMEntries_methods, VMEntries_methods_count());
@@ -63,18 +63,18 @@
     check_pending_exception("Could not register natives");
   }
 
-  c1x_compute_offsets();
+  graal_compute_offsets();
 
   {
     VM_ENTRY_MARK;
     HandleMark hm;
     VMExits::setDefaultOptions();
-    for (int i = 0; i < Arguments::num_c1x_args(); ++i) {
-      const char* arg = Arguments::c1x_args_array()[i];
+    for (int i = 0; i < Arguments::num_graal_args(); ++i) {
+      const char* arg = Arguments::graal_args_array()[i];
       Handle option = java_lang_String::create_from_str(arg, THREAD);
       jboolean result = VMExits::setOption(option);
       if (!result) {
-        tty->print_cr("Invalid option for C1X!");
+        tty->print_cr("Invalid option for graal!");
         vm_abort(false);
       }
     }
@@ -83,7 +83,7 @@
   }
 }
 
-void C1XCompiler::initialize_buffer_blob() {
+void GraalCompiler::initialize_buffer_blob() {
 
   CompilerThread* THREAD = CompilerThread::current();
   if (THREAD->get_buffer_blob() == NULL) {
@@ -91,7 +91,7 @@
     // NMethodSizeLimit plus some extra space for constants.
     int code_buffer_size = Compilation::desired_max_code_buffer_size() +
       Compilation::desired_max_constant_size();
-    BufferBlob* blob = BufferBlob::create("C1X temporary CodeBuffer",
+    BufferBlob* blob = BufferBlob::create("graal temporary CodeBuffer",
                                           code_buffer_size);
     guarantee(blob != NULL, "must create code buffer");
     THREAD->set_buffer_blob(blob);
@@ -99,7 +99,7 @@
 }
 
 // Compilation entry point for methods
-void C1XCompiler::compile_method(ciEnv* env, ciMethod* target, int entry_bci) {
+void GraalCompiler::compile_method(ciEnv* env, ciMethod* target, int entry_bci) {
   initialize();
   VM_ENTRY_MARK;
   ResourceMark rm;
@@ -108,7 +108,7 @@
   initialize_buffer_blob();
   VmIds::initializeObjects();
 
-  TRACE_C1X_2("C1XCompiler::compile_method");
+  TRACE_graal_2("GraalCompiler::compile_method");
 
   CompilerThread::current()->set_compiling(true);
   methodOop method = (methodOop) target->get_oop();
@@ -116,15 +116,15 @@
   CompilerThread::current()->set_compiling(false);
 
   VmIds::cleanupLocalObjects();
-  TRACE_C1X_2("C1XCompiler::compile_method exit");
+  TRACE_graal_2("GraalCompiler::compile_method exit");
 }
 
 // Print compilation timers and statistics
-void C1XCompiler::print_timers() {
-  TRACE_C1X_1("C1XCompiler::print_timers");
+void GraalCompiler::print_timers() {
+  TRACE_graal_1("GraalCompiler::print_timers");
 }
 
-oop C1XCompiler::get_RiType(ciType *type, KlassHandle accessor, TRAPS) {
+oop GraalCompiler::get_RiType(ciType *type, KlassHandle accessor, TRAPS) {
   if (type->is_loaded()) {
     if (type->is_primitive_type()) {
       return VMExits::createRiTypePrimitive((int) type->basic_type(), THREAD);
@@ -138,7 +138,7 @@
   }
 }
 
-oop C1XCompiler::get_RiField(ciField *field, ciInstanceKlass* accessor_klass, KlassHandle accessor, Bytecodes::Code byteCode, TRAPS) {
+oop GraalCompiler::get_RiField(ciField *field, ciInstanceKlass* accessor_klass, KlassHandle accessor, Bytecodes::Code byteCode, TRAPS) {
   bool will_link = field->will_link_from_vm(accessor_klass, byteCode);
   int offset = (field->holder()->is_loaded() && will_link) ? field->offset() : -1;
   Handle field_name = VmIds::toString<Handle>(field->name()->get_symbol(), CHECK_0);
@@ -148,9 +148,9 @@
   return VMExits::createRiField(field_holder, field_name, field_type, offset, flags, THREAD);
 }
 
-oop C1XCompiler::createHotSpotTypeResolved(KlassHandle klass, Handle name, TRAPS) {
-  if (klass->c1x_mirror() != NULL) {
-    return klass->c1x_mirror();
+oop GraalCompiler::createHotSpotTypeResolved(KlassHandle klass, Handle name, TRAPS) {
+  if (klass->graal_mirror() != NULL) {
+    return klass->graal_mirror();
   }
 
   instanceKlass::cast(HotSpotTypeResolved::klass())->initialize(CHECK_NULL);
@@ -188,12 +188,12 @@
   HotSpotTypeResolved::set_hasSubclass(obj, false);
   HotSpotTypeResolved::set_hasFinalizableSubclass(obj, false);
 
-  klass->set_c1x_mirror(obj());
+  klass->set_graal_mirror(obj());
 
   return obj();
 }
 
-BasicType C1XCompiler::kindToBasicType(jchar ch) {
+BasicType GraalCompiler::kindToBasicType(jchar ch) {
   switch(ch) {
     case 'z': return T_BOOLEAN;
     case 'b': return T_BYTE;
--- a/src/share/vm/graal/graalCompiler.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalCompiler.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -23,22 +23,22 @@
 
 #include "compiler/abstractCompiler.hpp"
 
-class C1XCompiler : public AbstractCompiler {
+class GraalCompiler : public AbstractCompiler {
 
 private:
 
   bool                  _initialized;
 
-  static C1XCompiler*   _instance;
+  static GraalCompiler*   _instance;
 
 public:
 
-  C1XCompiler();
+  GraalCompiler();
 
-  static C1XCompiler* instance() { return _instance; }
+  static GraalCompiler* instance() { return _instance; }
 
 
-  virtual const char* name() { return "C1X"; }
+  virtual const char* name() { return "G"; }
 
   // Native / OSR not supported
   virtual bool supports_native()                 { return false; }
@@ -79,19 +79,19 @@
 
 // Tracing macros
 
-#define IF_TRACE_C1X_1 if (!(TraceC1X >= 1)) ; else
-#define IF_TRACE_C1X_2 if (!(TraceC1X >= 2)) ; else
-#define IF_TRACE_C1X_3 if (!(TraceC1X >= 3)) ; else
-#define IF_TRACE_C1X_4 if (!(TraceC1X >= 4)) ; else
-#define IF_TRACE_C1X_5 if (!(TraceC1X >= 5)) ; else
+#define IF_TRACE_graal_1 if (!(Tracegraal >= 1)) ; else
+#define IF_TRACE_graal_2 if (!(Tracegraal >= 2)) ; else
+#define IF_TRACE_graal_3 if (!(Tracegraal >= 3)) ; else
+#define IF_TRACE_graal_4 if (!(Tracegraal >= 4)) ; else
+#define IF_TRACE_graal_5 if (!(Tracegraal >= 5)) ; else
 
 // using commas and else to keep one-instruction semantics
 
-#define TRACE_C1X_1 if (!(TraceC1X >= 1 && (tty->print("TraceC1X-1: "), true))) ; else tty->print_cr
-#define TRACE_C1X_2 if (!(TraceC1X >= 2 && (tty->print("   TraceC1X-2: "), true))) ; else tty->print_cr
-#define TRACE_C1X_3 if (!(TraceC1X >= 3 && (tty->print("      TraceC1X-3: "), true))) ; else tty->print_cr
-#define TRACE_C1X_4 if (!(TraceC1X >= 4 && (tty->print("         TraceC1X-4: "), true))) ; else tty->print_cr
-#define TRACE_C1X_5 if (!(TraceC1X >= 5 && (tty->print("            TraceC1X-5: "), true))) ; else tty->print_cr
+#define TRACE_graal_1 if (!(Tracegraal >= 1 && (tty->print("Tracegraal-1: "), true))) ; else tty->print_cr
+#define TRACE_graal_2 if (!(Tracegraal >= 2 && (tty->print("   Tracegraal-2: "), true))) ; else tty->print_cr
+#define TRACE_graal_3 if (!(Tracegraal >= 3 && (tty->print("      Tracegraal-3: "), true))) ; else tty->print_cr
+#define TRACE_graal_4 if (!(Tracegraal >= 4 && (tty->print("         Tracegraal-4: "), true))) ; else tty->print_cr
+#define TRACE_graal_5 if (!(Tracegraal >= 5 && (tty->print("            Tracegraal-5: "), true))) ; else tty->print_cr
 
 
 
--- a/src/share/vm/graal/graalJavaAccess.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalJavaAccess.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -21,7 +21,7 @@
  * questions.
  */
 
-void c1x_compute_offsets();
+void graal_compute_offsets();
 
 #include "classfile/systemDictionary.hpp"
 #include "oops/instanceMirrorKlass.hpp"
@@ -208,7 +208,7 @@
 #define START_CLASS(name)                       \
   class name : AllStatic {                      \
   private:                                      \
-    friend class C1XCompiler;                   \
+    friend class GraalCompiler;                   \
     static void check(oop obj) { assert(obj != NULL, "NULL field access of class " #name); assert(obj->is_a(SystemDictionary::name##_klass()), "wrong class, " #name " expected"); } \
     static void compute_offsets();              \
   public:                                       \
--- a/src/share/vm/graal/graalVMEntries.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalVMEntries.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -22,18 +22,18 @@
  */
 
 #include "precompiled.hpp"
-#include "c1x/c1x_VMEntries.hpp"
-#include "c1x/c1x_Compiler.hpp"
-#include "c1x/c1x_JavaAccess.hpp"
-#include "c1x/c1x_CodeInstaller.hpp"
-#include "c1x/c1x_VMExits.hpp"
-#include "c1x/c1x_VmIds.hpp"
+#include "graal/graalVMEntries.hpp"
+#include "graal/graalCompiler.hpp"
+#include "graal/graalJavaAccess.hpp"
+#include "graal/graalCodeInstaller.hpp"
+#include "graal/graalVMExits.hpp"
+#include "graal/graalVmIds.hpp"
 #include "c1/c1_Runtime1.hpp"
 #include "memory/oopFactory.hpp"
 
 // public byte[] RiMethod_code(long vmId);
 JNIEXPORT jbyteArray JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1code(JNIEnv *env, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_code");
+  TRACE_graal_3("VMEntries::RiMethod_code");
   methodHandle method = VmIds::get<methodOop>(vmId);
   int code_size = method->code_size();
   jbyteArray result = env->NewByteArray(code_size);
@@ -43,29 +43,29 @@
 
 // public int RiMethod_maxStackSize(long vmId);
 JNIEXPORT jint JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1maxStackSize(JNIEnv *, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_maxStackSize");
+  TRACE_graal_3("VMEntries::RiMethod_maxStackSize");
   return VmIds::get<methodOop>(vmId)->max_stack();
 }
 
 // public int RiMethod_maxLocals(long vmId);
 JNIEXPORT jint JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1maxLocals(JNIEnv *, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_maxLocals");
+  TRACE_graal_3("VMEntries::RiMethod_maxLocals");
   return VmIds::get<methodOop>(vmId)->max_locals();
 }
 
 // public RiType RiMethod_holder(long vmId);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1holder(JNIEnv *, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_holder");
+  TRACE_graal_3("VMEntries::RiMethod_holder");
   VM_ENTRY_MARK
   KlassHandle klass = VmIds::get<methodOop>(vmId)->method_holder();
   Handle name = VmIds::toString<Handle>(klass->name(), CHECK_NULL);
-  oop holder = C1XCompiler::createHotSpotTypeResolved(klass, name, CHECK_NULL);
+  oop holder = GraalCompiler::createHotSpotTypeResolved(klass, name, CHECK_NULL);
   return JNIHandles::make_local(THREAD, holder);
 }
 
 // public String RiMethod_signature(long vmId);
 JNIEXPORT jstring JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1signature(JNIEnv *env, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_signature");
+  TRACE_graal_3("VMEntries::RiMethod_signature");
   VM_ENTRY_MARK
   methodOop method = VmIds::get<methodOop>(vmId);
   return VmIds::toString<jstring>(method->signature(), THREAD);
@@ -73,13 +73,13 @@
 
 // public int RiMethod_accessFlags(long vmId);
 JNIEXPORT jint JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1accessFlags(JNIEnv *, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_accessFlags");
+  TRACE_graal_3("VMEntries::RiMethod_accessFlags");
   return VmIds::get<methodOop>(vmId)->access_flags().as_int();
 }
 
 // public RiExceptionHandler[] RiMethod_exceptionHandlers(long vmId);
 JNIEXPORT jobjectArray JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1exceptionHandlers(JNIEnv *, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_exceptionHandlers");
+  TRACE_graal_3("VMEntries::RiMethod_exceptionHandlers");
   VM_ENTRY_MARK
   methodHandle method = VmIds::get<methodOop>(vmId);
   typeArrayHandle handlers = method->exception_table();
@@ -105,7 +105,7 @@
       ciInstanceKlass* loading_klass = (ciInstanceKlass *) CURRENT_ENV->get_object(method->method_holder());
       bool is_accessible = false;
       ciKlass *klass = CURRENT_ENV->get_klass_by_index(cp, catch_class_index, is_accessible, loading_klass);
-      oop catch_class = C1XCompiler::get_RiType(klass, method->method_holder(), CHECK_NULL);
+      oop catch_class = GraalCompiler::get_RiType(klass, method->method_holder(), CHECK_NULL);
 
       HotSpotExceptionHandler::set_catchClass(entry, catch_class);
     }
@@ -117,7 +117,7 @@
 
 // public boolean RiMethod_hasBalancedMonitors(long vmId);
 JNIEXPORT jint JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1hasBalancedMonitors(JNIEnv *, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_hasBalancedMonitors");
+  TRACE_graal_3("VMEntries::RiMethod_hasBalancedMonitors");
   ciMethod* cimethod;
   {
     VM_ENTRY_MARK;
@@ -128,7 +128,7 @@
 
 // public boolean RiMethod_uniqueConcreteMethod(long vmId);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiMethod_1uniqueConcreteMethod(JNIEnv *, jobject, jlong vmId) {
-  TRACE_C1X_3("VMEntries::RiMethod_uniqueConcreteMethod");
+  TRACE_graal_3("VMEntries::RiMethod_uniqueConcreteMethod");
   VM_ENTRY_MARK;
   ciMethod* cimethod = (ciMethod*)CURRENT_ENV->get_object(VmIds::get<methodOop>(vmId));
   if (cimethod->holder()->is_interface()) {
@@ -160,7 +160,7 @@
 
 // public RiType RiSignature_lookupType(String returnType, HotSpotTypeResolved accessingClass);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiSignature_1lookupType(JNIEnv *env, jobject, jstring jname, jobject accessingClass) {
-  TRACE_C1X_3("VMEntries::RiSignature_lookupType");
+  TRACE_graal_3("VMEntries::RiSignature_lookupType");
   VM_ENTRY_MARK;
 
   Symbol* nameSymbol = VmIds::toSymbol(jname);
@@ -200,7 +200,7 @@
       }
     }
     if (resolved_type != NULL) {
-      result = C1XCompiler::createHotSpotTypeResolved(resolved_type, name, CHECK_NULL);
+      result = GraalCompiler::createHotSpotTypeResolved(resolved_type, name, CHECK_NULL);
     } else {
       result = VMExits::createRiTypeUnresolved(name, THREAD);
     }
@@ -211,7 +211,7 @@
 
 // public Object RiConstantPool_lookupConstant(long vmId, int cpi);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiConstantPool_1lookupConstant(JNIEnv *env, jobject, jlong vmId, jint index) {
-  TRACE_C1X_3("VMEntries::RiConstantPool_lookupConstant");
+  TRACE_graal_3("VMEntries::RiConstantPool_lookupConstant");
   VM_ENTRY_MARK;
 
   constantPoolOop cp = VmIds::get<constantPoolOop>(vmId);
@@ -244,7 +244,7 @@
     bool ignore;
     ciInstanceKlass* accessor = (ciInstanceKlass*) ciEnv::current()->get_object(cp->pool_holder());
     ciKlass* klass = ciEnv::current()->get_klass_by_index(cp, index, ignore, accessor);
-    result = C1XCompiler::get_RiType(klass, cp->pool_holder(), CHECK_NULL);
+    result = GraalCompiler::get_RiType(klass, cp->pool_holder(), CHECK_NULL);
   } else if (tag.is_object()) {
     oop obj = cp->object_at(index);
     assert(obj->is_instance(), "must be an instance");
@@ -258,10 +258,10 @@
 
 // public RiMethod RiConstantPool_lookupMethod(long vmId, int cpi, byte byteCode);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiConstantPool_1lookupMethod(JNIEnv *env, jobject, jlong vmId, jint index, jbyte byteCode) {
-  TRACE_C1X_3("VMEntries::RiConstantPool_lookupMethod");
+  TRACE_graal_3("VMEntries::RiConstantPool_lookupMethod");
   VM_ENTRY_MARK;
 
-  index = C1XCompiler::to_cp_index_u2(index);
+  index = GraalCompiler::to_cp_index_u2(index);
   constantPoolHandle cp = VmIds::get<constantPoolOop>(vmId);
 
   Bytecodes::Code bc = (Bytecodes::Code) (((int) byteCode) & 0xFF);
@@ -274,7 +274,7 @@
   } else {
     Handle name = VmIds::toString<Handle>(cimethod->name()->get_symbol(), CHECK_NULL);
     Handle signature = VmIds::toString<Handle>(cimethod->signature()->as_symbol()->get_symbol(), CHECK_NULL);
-    Handle holder = C1XCompiler::get_RiType(cimethod->holder(), cp->klass(), THREAD);
+    Handle holder = GraalCompiler::get_RiType(cimethod->holder(), cp->klass(), THREAD);
     return JNIHandles::make_local(THREAD, VMExits::createRiMethodUnresolved(name, signature, holder, THREAD));
   }
 }
@@ -287,7 +287,7 @@
 
 // public RiType RiConstantPool_lookupType(long vmId, int cpi);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiConstantPool_1lookupType(JNIEnv *env, jobject, jlong vmId, jint index) {
-  TRACE_C1X_3("VMEntries::RiConstantPool_lookupType");
+  TRACE_graal_3("VMEntries::RiConstantPool_lookupType");
   VM_ENTRY_MARK;
 
   constantPoolOop cp = VmIds::get<constantPoolOop>(vmId);
@@ -295,22 +295,22 @@
   ciInstanceKlass* loading_klass = (ciInstanceKlass *) CURRENT_ENV->get_object(cp->pool_holder());
   bool is_accessible = false;
   ciKlass *klass = CURRENT_ENV->get_klass_by_index(cp, index, is_accessible, loading_klass);
-  return JNIHandles::make_local(THREAD, C1XCompiler::get_RiType(klass, cp->klass(), THREAD));
+  return JNIHandles::make_local(THREAD, GraalCompiler::get_RiType(klass, cp->klass(), THREAD));
 }
 
 // public RiField RiConstantPool_lookupField(long vmId, int cpi);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiConstantPool_1lookupField(JNIEnv *env, jobject, jlong vmId, jint index, jbyte byteCode) {
-  TRACE_C1X_3("VMEntries::RiConstantPool_lookupField");
+  TRACE_graal_3("VMEntries::RiConstantPool_lookupField");
   VM_ENTRY_MARK;
 
-  index = C1XCompiler::to_cp_index_u2(index);
+  index = GraalCompiler::to_cp_index_u2(index);
   constantPoolOop cp = VmIds::get<constantPoolOop>(vmId);
 
   ciInstanceKlass* loading_klass = (ciInstanceKlass *) CURRENT_ENV->get_object(cp->pool_holder());
   ciField *field = CURRENT_ENV->get_field_by_index(loading_klass, index);
   
   Bytecodes::Code code = (Bytecodes::Code)(((int) byteCode) & 0xFF);
-  Handle field_handle = C1XCompiler::get_RiField(field, loading_klass, cp->pool_holder(), code, THREAD);
+  Handle field_handle = GraalCompiler::get_RiField(field, loading_klass, cp->pool_holder(), code, THREAD);
   bool is_constant = field->is_constant();
   if (is_constant && field->is_static()) {
     ciConstant constant = field->constant_value();
@@ -364,7 +364,7 @@
 
 // public RiConstantPool RiType_constantPool(HotSpotTypeResolved klass);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiType_1constantPool(JNIEnv *, jobject, jobject klass) {
-  TRACE_C1X_3("VMEntries::RiType_constantPool");
+  TRACE_graal_3("VMEntries::RiType_constantPool");
   VM_ENTRY_MARK;
 
   assert(JNIHandles::resolve(klass) != NULL, "");
@@ -374,7 +374,7 @@
 
 // public RiMethod RiType_resolveMethodImpl(HotSpotTypeResolved klass, String name, String signature);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiType_3resolveMethodImpl(JNIEnv *, jobject, jobject resolved_type, jstring name, jstring signature) {
-  TRACE_C1X_3("VMEntries::RiType_resolveMethodImpl");
+  TRACE_graal_3("VMEntries::RiType_resolveMethodImpl");
   VM_ENTRY_MARK;
 
   assert(JNIHandles::resolve(resolved_type) != NULL, "");
@@ -383,7 +383,7 @@
   Symbol* signature_symbol = VmIds::toSymbol(signature);
   methodOop method = klass->klass_part()->lookup_method(name_symbol, signature_symbol);
   if (method == NULL) {
-    if (TraceC1X >= 3) {
+    if (Tracegraal >= 3) {
       ResourceMark rm;
       tty->print_cr("Could not resolve method %s %s on klass %s", name_symbol->as_C_string(), signature_symbol->as_C_string(), klass->klass_part()->name()->as_C_string());
     }
@@ -394,7 +394,7 @@
 
 // public boolean RiType_isSubtypeOf(HotSpotTypeResolved klass, RiType other);
 JNIEXPORT jboolean JNICALL Java_com_oracle_graal_runtime_VMEntries_RiType_2isSubtypeOf(JNIEnv *, jobject, jobject klass, jobject jother) {
-  TRACE_C1X_3("VMEntries::RiType_isSubtypeOf");
+  TRACE_graal_3("VMEntries::RiType_isSubtypeOf");
   oop other = JNIHandles::resolve(jother);
   assert(other->is_a(HotSpotTypeResolved::klass()), "resolved hotspot type expected");
   assert(JNIHandles::resolve(klass) != NULL, "");
@@ -412,7 +412,7 @@
 
 // public RiType RiType_componentType(HotSpotResolvedType klass);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiType_1componentType(JNIEnv *, jobject, jobject klass) {
-  TRACE_C1X_3("VMEntries::RiType_componentType");
+  TRACE_graal_3("VMEntries::RiType_componentType");
   ciArrayKlass* array_klass;
   {
     VM_ENTRY_MARK;
@@ -423,12 +423,12 @@
 
   VM_ENTRY_MARK;
   assert(JNIHandles::resolve(klass) != NULL, "");
-  return JNIHandles::make_local(C1XCompiler::get_RiType(element_type, java_lang_Class::as_klassOop(HotSpotTypeResolved::javaMirror(klass)), THREAD));
+  return JNIHandles::make_local(GraalCompiler::get_RiType(element_type, java_lang_Class::as_klassOop(HotSpotTypeResolved::javaMirror(klass)), THREAD));
 }
 
 // public RiType RiType_superType(HotSpotResolvedType klass);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiType_1superType(JNIEnv *, jobject, jobject klass) {
-  TRACE_C1X_3("VMEntries::RiType_superType");
+  TRACE_graal_3("VMEntries::RiType_superType");
   VM_ENTRY_MARK;
   KlassHandle klass_handle(java_lang_Class::as_klassOop(HotSpotTypeResolved::javaMirror(klass)));
   ciInstanceKlass* k = NULL;
@@ -442,7 +442,7 @@
   }
 
   if (k != NULL) {
-    return JNIHandles::make_local(C1XCompiler::get_RiType(k, klass_handle, THREAD));
+    return JNIHandles::make_local(GraalCompiler::get_RiType(k, klass_handle, THREAD));
   } else {
     return NULL;
   }
@@ -450,7 +450,7 @@
 
 // public RiType RiType_uniqueConcreteSubtype(HotSpotResolvedType klass);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiType_1uniqueConcreteSubtype(JNIEnv *, jobject, jobject klass) {
-  TRACE_C1X_3("VMEntries::RiType_uniqueConcreteSubtype");
+  TRACE_graal_3("VMEntries::RiType_uniqueConcreteSubtype");
   Thread* THREAD = Thread::current();
   KlassHandle klass_handle(java_lang_Class::as_klassOop(HotSpotTypeResolved::javaMirror(klass)));
   ciInstanceKlass* k = NULL;
@@ -463,7 +463,7 @@
     ciInstanceKlass* sub = k->unique_concrete_subklass();
     if (sub != NULL && sub->is_leaf_type()) {
       VM_ENTRY_MARK;
-      return JNIHandles::make_local(C1XCompiler::get_RiType(sub, klass_handle, THREAD));
+      return JNIHandles::make_local(GraalCompiler::get_RiType(sub, klass_handle, THREAD));
     }
   } else if (k->is_leaf_type()) {
     assert(!k->is_interface(), "");
@@ -475,28 +475,28 @@
 
 // public RiType RiType_arrayOf(HotSpotTypeResolved klass);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_RiType_1arrayOf(JNIEnv *, jobject, jobject klass) {
-  TRACE_C1X_3("VMEntries::RiType_arrayOf");
+  TRACE_graal_3("VMEntries::RiType_arrayOf");
   VM_ENTRY_MARK;
 
   KlassHandle klass_handle(java_lang_Class::as_klassOop(HotSpotTypeResolved::javaMirror(klass)));
   KlassHandle array = klass_handle->array_klass(THREAD);
   Handle name = VmIds::toString<Handle>(array->name(), CHECK_NULL);
-  return JNIHandles::make_local(THREAD, C1XCompiler::createHotSpotTypeResolved(array, name, THREAD));
+  return JNIHandles::make_local(THREAD, GraalCompiler::createHotSpotTypeResolved(array, name, THREAD));
 }
 
 // public RiType getPrimitiveArrayType(CiKind kind);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_getPrimitiveArrayType(JNIEnv *env, jobject, jobject kind) {
-  TRACE_C1X_3("VMEntries::VMEntries_getPrimitiveArrayType");
+  TRACE_graal_3("VMEntries::VMEntries_getPrimitiveArrayType");
   VM_ENTRY_MARK;
-  BasicType type = C1XCompiler::kindToBasicType(CiKind::typeChar(kind));
+  BasicType type = GraalCompiler::kindToBasicType(CiKind::typeChar(kind));
   assert(type != T_OBJECT, "primitive type expecteds");
   ciKlass* klass = ciTypeArrayKlass::make(type);
-  return JNIHandles::make_local(THREAD, C1XCompiler::get_RiType(klass, KlassHandle(), THREAD));
+  return JNIHandles::make_local(THREAD, GraalCompiler::get_RiType(klass, KlassHandle(), THREAD));
 }
 
 // public RiType getType(Class<?> javaClass);
 JNIEXPORT jobject JNICALL Java_com_oracle_graal_runtime_VMEntries_getType(JNIEnv *env, jobject, jobject javaClass) {
-  TRACE_C1X_3("VMEntries::VMEntries_getType");
+  TRACE_graal_3("VMEntries::VMEntries_getType");
   VM_ENTRY_MARK;
   oop javaClassOop = JNIHandles::resolve(javaClass);
   if (javaClassOop == NULL) {
@@ -509,7 +509,7 @@
     KlassHandle klass = java_lang_Class::as_klassOop(javaClassOop);
     Handle name = java_lang_String::create_from_symbol(klass->name(), CHECK_NULL);
 
-    oop type = C1XCompiler::createHotSpotTypeResolved(klass, name, CHECK_NULL);
+    oop type = GraalCompiler::createHotSpotTypeResolved(klass, name, CHECK_NULL);
     return JNIHandles::make_local(THREAD, type);
   }
 }
@@ -519,7 +519,7 @@
 jfieldID getFieldID(JNIEnv* env, jobject obj, const char* name, const char* sig) {
   jfieldID id = env->GetFieldID(env->GetObjectClass(obj), name, sig);
   if (id == NULL) {
-    TRACE_C1X_1("field not found: %s (%s)", name, sig);
+    TRACE_graal_1("field not found: %s (%s)", name, sig);
     fatal("field not found");
   }
   return id;
@@ -568,12 +568,12 @@
   set_int(env, config, "instanceHeaderPrototypeOffset", Klass::prototype_header_offset_in_bytes() + klassOopDesc::klass_part_offset_in_bytes());
   set_int(env, config, "threadExceptionOopOffset", in_bytes(JavaThread::exception_oop_offset()));
   set_int(env, config, "threadExceptionPcOffset", in_bytes(JavaThread::exception_pc_offset()));
-  set_int(env, config, "threadMultiNewArrayStorage", in_bytes(JavaThread::c1x_multinewarray_storage_offset()));
+  set_int(env, config, "threadMultiNewArrayStorage", in_bytes(JavaThread::graal_multinewarray_storage_offset()));
   set_int(env, config, "classMirrorOffset", klassOopDesc::klass_part_offset_in_bytes() + Klass::java_mirror_offset_in_bytes());
 
   set_long(env, config, "debugStub", VmIds::addStub((address)warning));
   set_long(env, config, "instanceofStub", VmIds::addStub(Runtime1::entry_for(Runtime1::slow_subtype_check_id)));
-  set_long(env, config, "verifyPointerStub", VmIds::addStub(Runtime1::entry_for(Runtime1::c1x_verify_pointer_id)));
+  set_long(env, config, "verifyPointerStub", VmIds::addStub(Runtime1::entry_for(Runtime1::graal_verify_pointer_id)));
   set_long(env, config, "newInstanceStub", VmIds::addStub(Runtime1::entry_for(Runtime1::fast_new_instance_init_check_id)));
   set_long(env, config, "unresolvedNewInstanceStub", VmIds::addStub(Runtime1::entry_for(Runtime1::new_instance_id)));
   set_long(env, config, "newTypeArrayStub", VmIds::addStub(Runtime1::entry_for(Runtime1::new_type_array_id)));
@@ -583,13 +583,13 @@
   set_long(env, config, "accessFieldStub", VmIds::addStub(Runtime1::entry_for(Runtime1::access_field_patching_id)));
   set_long(env, config, "resolveStaticCallStub", VmIds::addStub(SharedRuntime::get_resolve_static_call_stub()));
   set_long(env, config, "inlineCacheMissStub", VmIds::addStub(SharedRuntime::get_ic_miss_stub()));
-  set_long(env, config, "unwindExceptionStub", VmIds::addStub(Runtime1::entry_for(Runtime1::c1x_unwind_exception_call_id)));
+  set_long(env, config, "unwindExceptionStub", VmIds::addStub(Runtime1::entry_for(Runtime1::graal_unwind_exception_call_id)));
   set_long(env, config, "handleExceptionStub", VmIds::addStub(Runtime1::entry_for(Runtime1::handle_exception_nofpu_id)));
   set_long(env, config, "handleDeoptStub", VmIds::addStub(SharedRuntime::deopt_blob()->unpack()));
   set_long(env, config, "monitorEnterStub", VmIds::addStub(Runtime1::entry_for(Runtime1::monitorenter_id)));
   set_long(env, config, "monitorExitStub", VmIds::addStub(Runtime1::entry_for(Runtime1::monitorexit_id)));
-  set_long(env, config, "fastMonitorEnterStub", VmIds::addStub(Runtime1::entry_for(Runtime1::c1x_monitorenter_id)));
-  set_long(env, config, "fastMonitorExitStub", VmIds::addStub(Runtime1::entry_for(Runtime1::c1x_monitorexit_id)));
+  set_long(env, config, "fastMonitorEnterStub", VmIds::addStub(Runtime1::entry_for(Runtime1::graal_monitorenter_id)));
+  set_long(env, config, "fastMonitorExitStub", VmIds::addStub(Runtime1::entry_for(Runtime1::graal_monitorexit_id)));
   set_long(env, config, "safepointPollingAddress", (jlong)(os::get_polling_page() + (SafepointPollOffset % os::vm_page_size())));
 
   BarrierSet* bs = Universe::heap()->barrier_set();
@@ -642,7 +642,7 @@
 
 // public void recordBailout(String reason);
 JNIEXPORT void JNICALL Java_com_oracle_graal_runtime_VMEntries_recordBailout(JNIEnv *jniEnv, jobject, jobject message) {
-  if (C1XBailoutIsFatal) {
+  if (GraalBailoutIsFatal) {
     Handle msg = JNIHandles::resolve(message);
     if (!msg.is_null()) {
       java_lang_String::print(msg, tty);
--- a/src/share/vm/graal/graalVMExits.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalVMExits.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -22,7 +22,7 @@
  */
 
 #include "precompiled.hpp"
-#include "c1x/c1x_VMExits.hpp"
+#include "graal/graalVMExits.hpp"
 
 // this is a *global* handle
 jobject VMExits::_compilerPermObject;
@@ -31,8 +31,8 @@
 
 KlassHandle VMExits::vmExitsKlass() {
   if (JNIHandles::resolve(_vmExitsPermKlass) == NULL) {
-    klassOop result = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_c1x_VMExits(), SystemDictionary::java_system_loader(), NULL, Thread::current());
-    check_not_null(result, "Couldn't find class com.sun.hotspot.c1x.VMExits");
+    klassOop result = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_graal_VMExits(), SystemDictionary::java_system_loader(), NULL, Thread::current());
+    check_not_null(result, "Couldn't find class com.sun.hotspot.graal.VMExits");
     _vmExitsPermKlass = JNIHandles::make_global(result);
   }
   return KlassHandle((klassOop)JNIHandles::resolve_non_null(_vmExitsPermKlass));
@@ -40,8 +40,8 @@
 
 Handle VMExits::compilerInstance() {
   if (JNIHandles::resolve(_compilerPermObject) == NULL) {
-    KlassHandle compilerImplKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_c1x_CompilerImpl(), SystemDictionary::java_system_loader(), NULL, Thread::current());
-    check_not_null(compilerImplKlass(), "Couldn't find class com.sun.hotspot.c1x.CompilerImpl");
+    KlassHandle compilerImplKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_graal_CompilerImpl(), SystemDictionary::java_system_loader(), NULL, Thread::current());
+    check_not_null(compilerImplKlass(), "Couldn't find class com.sun.hotspot.graal.CompilerImpl");
 
     JavaValue result(T_OBJECT);
     JavaCalls::call_static(&result, compilerImplKlass, vmSymbols::getInstance_name(), vmSymbols::getInstance_signature(), Thread::current());
@@ -53,8 +53,8 @@
 
 Handle VMExits::instance() {
   if (JNIHandles::resolve(_vmExitsPermObject) == NULL) {
-    KlassHandle compilerKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_c1x_Compiler(), SystemDictionary::java_system_loader(), NULL, Thread::current());
-    check_not_null(compilerKlass(), "Couldn't find class com.sun.hotspot.c1x.Compiler");
+    KlassHandle compilerKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_graal_Compiler(), SystemDictionary::java_system_loader(), NULL, Thread::current());
+    check_not_null(compilerKlass(), "Couldn't find class com.sun.hotspot.graal.Compiler");
 
     JavaValue result(T_OBJECT);
     JavaCallArguments args;
@@ -67,8 +67,8 @@
 }
 
 void VMExits::initializeCompiler() {
-  KlassHandle compilerImplKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_c1x_CompilerImpl(), SystemDictionary::java_system_loader(), NULL, Thread::current());
-  check_not_null(compilerImplKlass(), "Couldn't find class com.sun.hotspot.c1x.CompilerImpl");
+  KlassHandle compilerImplKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_graal_CompilerImpl(), SystemDictionary::java_system_loader(), NULL, Thread::current());
+  check_not_null(compilerImplKlass(), "Couldn't find class com.sun.hotspot.graal.CompilerImpl");
 
   JavaValue result(T_VOID);
   JavaCalls::call_static(&result, compilerImplKlass, vmSymbols::initialize_name(), vmSymbols::void_method_signature(), Thread::current());
@@ -77,8 +77,8 @@
 
 jboolean VMExits::setOption(Handle option) {
   assert(!option.is_null(), "");
-  KlassHandle compilerKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_c1x_HotSpotOptions(), SystemDictionary::java_system_loader(), NULL, Thread::current());
-  check_not_null(compilerKlass(), "Couldn't find class com.sun.hotspot.c1x.HotSpotOptions");
+  KlassHandle compilerKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_graal_HotSpotOptions(), SystemDictionary::java_system_loader(), NULL, Thread::current());
+  check_not_null(compilerKlass(), "Couldn't find class com.sun.hotspot.graal.HotSpotOptions");
 
   Thread* THREAD = Thread::current();
   JavaValue result(T_BOOLEAN);
@@ -88,8 +88,8 @@
 }
 
 void VMExits::setDefaultOptions() {
-  KlassHandle compilerKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_c1x_HotSpotOptions(), SystemDictionary::java_system_loader(), NULL, Thread::current());
-  check_not_null(compilerKlass(), "Couldn't find class com.sun.hotspot.c1x.HotSpotOptions");
+  KlassHandle compilerKlass = SystemDictionary::resolve_or_null(vmSymbols::com_sun_hotspot_graal_HotSpotOptions(), SystemDictionary::java_system_loader(), NULL, Thread::current());
+  check_not_null(compilerKlass(), "Couldn't find class com.sun.hotspot.graal.HotSpotOptions");
 
   Thread* THREAD = Thread::current();
   JavaValue result(T_VOID);
--- a/src/share/vm/graal/graalVmIds.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalVmIds.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -22,7 +22,7 @@
  */
 
 #include "precompiled.hpp"
-#include "c1x/c1x_VmIds.hpp"
+#include "graal/graalVmIds.hpp"
 #include "ci/ciUtilities.hpp"
 
 // VmIds implementation
--- a/src/share/vm/interpreter/rewriter.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/interpreter/rewriter.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -109,7 +109,7 @@
   while (!bcs.is_last_bytecode()) {
     Bytecodes::Code opcode = bcs.raw_next();
     switch (opcode) {
-      case Bytecodes::_return: if (!UseC1X) { *bcs.bcp() = Bytecodes::_return_register_finalizer; } break;
+      case Bytecodes::_return: if (!UseGraal) { *bcs.bcp() = Bytecodes::_return_register_finalizer; } break;
 
       case Bytecodes::_istore:
       case Bytecodes::_lstore:
@@ -227,7 +227,7 @@
       switch (c) {
         case Bytecodes::_lookupswitch   : {
 #ifndef CC_INTERP
-          if (!UseC1X) {
+          if (!UseGraal) {
             Bytecode_lookupswitch bc(method, bcp);
             (*bcp) = (
               bc.number_of_pairs() < BinarySwitchThreshold
--- a/src/share/vm/oops/klass.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/oops/klass.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -148,7 +148,7 @@
   }
 
   kl->set_java_mirror(NULL);
-  kl->set_c1x_mirror(NULL);
+  kl->set_graal_mirror(NULL);
   kl->set_modifier_flags(0);
   kl->set_layout_helper(Klass::_lh_neutral_value);
   kl->set_name(NULL);
--- a/src/share/vm/oops/klass.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/oops/klass.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -238,7 +238,7 @@
   // java/lang/Class instance mirroring this class
   oop       _java_mirror;
   // com/oracle/max/graal/runtime/HotSpotTypeResolved mirroring this class
-  oop       _c1x_mirror;
+  oop       _graal_mirror;
   // Superclass
   klassOop  _super;
   // First subclass (NULL if none); _subklass->next_sibling() is next one
@@ -336,9 +336,9 @@
   oop java_mirror() const              { return _java_mirror; }
   void set_java_mirror(oop m)          { oop_store((oop*) &_java_mirror, m); }
 
-  // c1x mirror
-  oop c1x_mirror() const               { return _c1x_mirror; }
-  void set_c1x_mirror(oop m)           { oop_store((oop*) &_c1x_mirror, m); }
+  // graal mirror
+  oop graal_mirror() const               { return _graal_mirror; }
+  void set_graal_mirror(oop m)           { oop_store((oop*) &_graal_mirror, m); }
 
   // modifier flags
   jint modifier_flags() const          { return _modifier_flags; }
@@ -368,7 +368,7 @@
   oop* adr_secondary_super_cache() const { return (oop*)&_secondary_super_cache; }
   oop* adr_secondary_supers()const { return (oop*)&_secondary_supers;  }
   oop* adr_java_mirror()     const { return (oop*)&_java_mirror;       }
-  oop* adr_c1x_mirror()      const { return (oop*)&_c1x_mirror;        }
+  oop* adr_graal_mirror()      const { return (oop*)&_graal_mirror;        }
   oop* adr_subklass()        const { return (oop*)&_subklass;          }
   oop* adr_next_sibling()    const { return (oop*)&_next_sibling;      }
 
--- a/src/share/vm/oops/klassKlass.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/oops/klassKlass.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -73,7 +73,7 @@
   MarkSweep::mark_and_push(k->adr_secondary_super_cache());
   MarkSweep::mark_and_push(k->adr_secondary_supers());
   MarkSweep::mark_and_push(k->adr_java_mirror());
-  MarkSweep::mark_and_push(k->adr_c1x_mirror());
+  MarkSweep::mark_and_push(k->adr_graal_mirror());
   // We follow the subklass and sibling links at the end of the
   // marking phase, since otherwise following them will prevent
   // class unloading (all classes are transitively linked from
@@ -93,7 +93,7 @@
   PSParallelCompact::mark_and_push(cm, k->adr_secondary_super_cache());
   PSParallelCompact::mark_and_push(cm, k->adr_secondary_supers());
   PSParallelCompact::mark_and_push(cm, k->adr_java_mirror());
-  PSParallelCompact::mark_and_push(cm, k->adr_c1x_mirror());
+  PSParallelCompact::mark_and_push(cm, k->adr_graal_mirror());
   // We follow the subklass and sibling links at the end of the
   // marking phase, since otherwise following them will prevent
   // class unloading (all classes are transitively linked from
@@ -113,7 +113,7 @@
   blk->do_oop(k->adr_secondary_super_cache());
   blk->do_oop(k->adr_secondary_supers());
   blk->do_oop(k->adr_java_mirror());
-  blk->do_oop(k->adr_c1x_mirror());
+  blk->do_oop(k->adr_graal_mirror());
   // The following are in the perm gen and are treated
   // specially in a later phase of a perm gen collection; ...
   assert(oop(k)->is_perm(), "should be in perm");
@@ -147,7 +147,7 @@
   if (mr.contains(adr)) blk->do_oop(adr);
   adr = k->adr_java_mirror();
   if (mr.contains(adr)) blk->do_oop(adr);
-  adr = k->adr_c1x_mirror();
+  adr = k->adr_graal_mirror();
   if (mr.contains(adr)) blk->do_oop(adr);
   // The following are "weak links" in the perm gen and are
   // treated specially in a later phase of a perm gen collection.
@@ -177,7 +177,7 @@
   MarkSweep::adjust_pointer(k->adr_secondary_super_cache());
   MarkSweep::adjust_pointer(k->adr_secondary_supers());
   MarkSweep::adjust_pointer(k->adr_java_mirror());
-  MarkSweep::adjust_pointer(k->adr_c1x_mirror());
+  MarkSweep::adjust_pointer(k->adr_graal_mirror());
   MarkSweep::adjust_pointer(k->adr_subklass());
   MarkSweep::adjust_pointer(k->adr_next_sibling());
   return size;
--- a/src/share/vm/prims/jni.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/prims/jni.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -3345,8 +3345,8 @@
        JvmtiExport::post_thread_start(thread);
     }
 
-    if (BootstrapC1X) {
-      CompileBroker::bootstrap_c1x();
+    if (Bootstrapgraal) {
+      CompileBroker::bootstrap_graal();
     }
 
     // Check if we should compile all classes on bootclasspath
--- a/src/share/vm/runtime/sharedRuntime.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/runtime/sharedRuntime.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -785,7 +785,7 @@
 #ifndef PRODUCT
           _implicit_null_throws++;
 #endif
-          if (UseC1X) {
+          if (UseGraal) {
             target_pc = deoptimization_continuation(thread, pc, nm);
           } else {
             target_pc = nm->continuation_for_implicit_exception(pc);
@@ -805,9 +805,9 @@
 #ifndef PRODUCT
         _implicit_div0_throws++;
 #endif
-        if (UseC1X) {
+        if (UseGraal) {
           if (TraceSignals) {
-            tty->print_cr("c1x implicit div0");
+            tty->print_cr("graal implicit div0");
           }
           target_pc = deoptimization_continuation(thread, pc, nm);
         } else {
--- a/src/cpu/x86/vm/c1_Runtime1_x86.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/cpu/x86/vm/c1_Runtime1_x86.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -592,8 +592,8 @@
 
 OopMapSet* Runtime1::generate_exception_throw(StubAssembler* sasm, address target, bool has_argument) {
   OopMapSet* oop_maps = new OopMapSet();
-  if (UseC1X) {
-    // c1x passes the argument in r10
+  if (UseGraal) {
+    // graal passes the argument in r10
     OopMap* oop_map = save_live_registers(sasm, 1);
 
     // now all registers are saved and can be used freely
@@ -772,7 +772,7 @@
   return oop_maps;
 }
 
-void Runtime1::c1x_generate_handle_exception(StubAssembler *sasm, OopMapSet* oop_maps, OopMap* oop_map) {
+void Runtime1::graal_generate_handle_exception(StubAssembler *sasm, OopMapSet* oop_maps, OopMap* oop_map) {
   NOT_LP64(fatal("64 bit only"));
   // incoming parameters
   const Register exception_oop = j_rarg0;
@@ -780,7 +780,7 @@
   const Register exception_pc = j_rarg1;
   const Register thread = r15_thread;
 
-  __ block_comment("c1x_generate_handle_exception");
+  __ block_comment("graal_generate_handle_exception");
 
   // verify that rax, contains a valid exception
   __ verify_not_null_oop(exception_oop);
@@ -1047,7 +1047,7 @@
   return oop_maps;
 }
 
-JRT_ENTRY(void, c1x_create_null_exception(JavaThread* thread))
+JRT_ENTRY(void, graal_create_null_exception(JavaThread* thread))
   thread->set_vm_result(Exceptions::new_exception(thread, vmSymbols::java_lang_NullPointerException(), NULL)());
 JRT_END
 
@@ -1346,8 +1346,8 @@
         // will be place in C abi locations
 
 #ifdef _LP64
-        __ verify_oop((UseC1X) ? j_rarg0 : c_rarg0);
-        __ mov(rax, (UseC1X) ? j_rarg0 : c_rarg0);
+        __ verify_oop((UseGraal) ? j_rarg0 : c_rarg0);
+        __ mov(rax, (UseGraal) ? j_rarg0 : c_rarg0);
 #else
         // The object is passed on the stack and we haven't pushed a
         // frame yet so it's one work away from top of stack.
@@ -1480,7 +1480,7 @@
 
         Label success;
         Label miss;
-        if (UseC1X) {
+        if (UseGraal) {
           // TODO this should really be within the XirSnippets
           __ check_klass_subtype_fast_path(rsi, rax, rcx, &success, &miss, NULL);
         };
@@ -1886,7 +1886,7 @@
       break;
 #endif // !SERIALGC
 
-    case c1x_unwind_exception_call_id: {
+    case graal_unwind_exception_call_id: {
       // remove the frame from the stack
       __ movptr(rsp, rbp);
       __ pop(rbp);
@@ -1900,7 +1900,7 @@
         __ enter();
         oop_maps = new OopMapSet();
         OopMap* oop_map = save_live_registers(sasm, 0);
-        int call_offset = __ call_RT(rax, noreg, (address)c1x_create_null_exception, 0);
+        int call_offset = __ call_RT(rax, noreg, (address)graal_create_null_exception, 0);
         oop_maps->add_gc_map(call_offset, oop_map);
         __ leave();
       }
@@ -1914,15 +1914,15 @@
       break;
     }
 
-    case c1x_handle_exception_id: {
-      StubFrame f(sasm, "c1x_handle_exception", dont_gc_arguments);
+    case graal_handle_exception_id: {
+      StubFrame f(sasm, "graal_handle_exception", dont_gc_arguments);
       oop_maps = new OopMapSet();
       OopMap* oop_map = save_live_registers(sasm, 1, false);
-      c1x_generate_handle_exception(sasm, oop_maps, oop_map);
+      graal_generate_handle_exception(sasm, oop_maps, oop_map);
       break;
     }
 
-    case c1x_slow_subtype_check_id: {
+    case graal_slow_subtype_check_id: {
       Label success;
       Label miss;
 
@@ -1941,13 +1941,13 @@
       break;
     }
 
-    case c1x_verify_pointer_id: {
-      __ verify_oop(r13, "c1x verify pointer");
+    case graal_verify_pointer_id: {
+      __ verify_oop(r13, "graal verify pointer");
       __ ret(0);
       break;
     }
 
-    case c1x_arithmetic_frem_id: {
+    case graal_arithmetic_frem_id: {
       __ subptr(rsp, 8);
       __ movflt(Address(rsp, 0), xmm1);
       __ fld_s(Address(rsp, 0));
@@ -1968,7 +1968,7 @@
       __ ret(0);
       break;
     }
-    case c1x_arithmetic_drem_id: {
+    case graal_arithmetic_drem_id: {
       __ subptr(rsp, 8);
       __ movdbl(Address(rsp, 0), xmm1);
       __ fld_d(Address(rsp, 0));
@@ -1989,7 +1989,7 @@
       __ ret(0);
       break;
     }
-    case c1x_monitorenter_id: {
+    case graal_monitorenter_id: {
       Label slow_case;
 
       Register obj = j_rarg0;
@@ -2008,7 +2008,7 @@
 
       __ bind(slow_case);
       {
-        StubFrame f(sasm, "c1x_monitorenter", dont_gc_arguments);
+        StubFrame f(sasm, "graal_monitorenter", dont_gc_arguments);
         OopMap* map = save_live_registers(sasm, 1, save_fpu_registers);
 
         // Called with store_parameter and not C abi
@@ -2021,7 +2021,7 @@
       __ ret(0);
       break;
     }
-    case c1x_monitorexit_id: {
+    case graal_monitorexit_id: {
       Label slow_case;
 
       Register obj = j_rarg0;
@@ -2042,7 +2042,7 @@
 
       __ bind(slow_case);
       {
-        StubFrame f(sasm, "c1x_monitorexit", dont_gc_arguments);
+        StubFrame f(sasm, "graal_monitorexit", dont_gc_arguments);
         OopMap* map = save_live_registers(sasm, 2, save_fpu_registers);
 
         // note: really a leaf routine but must setup last java sp
--- a/src/share/vm/code/nmethod.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/code/nmethod.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -818,8 +818,8 @@
     // Exception handler and deopt handler are in the stub section
     assert(offsets->value(CodeOffsets::Exceptions) != -1, "must be set");
     assert(offsets->value(CodeOffsets::Deopt     ) != -1, "must be set");
-    if (UseC1X) {
-      // c1x produces no (!) stub section
+    if (UseGraal) {
+      // graal produces no (!) stub section
       _exception_offset        = code_offset()          + offsets->value(CodeOffsets::Exceptions);
       _deoptimize_offset       = code_offset()          + offsets->value(CodeOffsets::Deopt);
       if (offsets->value(CodeOffsets::DeoptMH) != -1) {
@@ -2301,7 +2301,7 @@
         // information in a table.
         break;
     }
-    assert(UseC1X || stub == NULL || stub_contains(stub), "static call stub outside stub section");
+    assert(UseGraal || stub == NULL || stub_contains(stub), "static call stub outside stub section");
   }
 }
 
--- a/src/share/vm/code/nmethod.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/code/nmethod.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -591,9 +591,9 @@
   // Return true is the PC is one would expect if the frame is being deopted.
   bool is_deopt_pc      (address pc) { return is_deopt_entry(pc) || is_deopt_mh_entry(pc); }
 
   // (tw) When using C1X, the address might be off by 5 (because this is the size of the call instruction.
   // (tw) TODO: Replace this by a more general mechanism.
-  bool is_deopt_entry   (address pc) { return pc == deopt_handler_begin() || (UseC1X && pc == deopt_handler_begin() + 5); }
+  bool is_deopt_entry   (address pc) { return pc == deopt_handler_begin() || (UseGraal && pc == deopt_handler_begin() + 5); }
   bool is_deopt_mh_entry(address pc) { return pc == deopt_mh_handler_begin(); }
   // Accessor/mutator for the original pc of a frame before a frame was deopted.
   address get_original_pc(const frame* fr) { return *orig_pc_addr(fr); }
@@ -591,9 +591,9 @@
   bool is_deopt_pc      (address pc) { return is_deopt_entry(pc) || is_deopt_mh_entry(pc); }
 
-  // (tw) When using C1X, the address might be off by 5 (because this is the size of the call instruction.
+  // (tw) When using graal, the address might be off by 5 (because this is the size of the call instruction.
   // (tw) TODO: Replace this by a more general mechanism.
--- a/src/share/vm/compiler/compileBroker.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/compiler/compileBroker.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -44,7 +44,7 @@
 #include "runtime/sharedRuntime.hpp"
 #include "runtime/sweeper.hpp"
 #include "utilities/dtrace.hpp"
-#include "c1x/c1x_Compiler.hpp"
+#include "graal/graalCompiler.hpp"
 #ifdef COMPILER1
 #include "c1/c1_Compiler.hpp"
 #endif
@@ -627,14 +627,14 @@
   }
 }
 
-// Bootstrap the C1X compiler. Compiles all methods until compile queue is empty and no compilation is active.
-void CompileBroker::bootstrap_c1x() {
+// Bootstrap the graal compiler. Compiles all methods until compile queue is empty and no compilation is active.
+void CompileBroker::bootstrap_graal() {
   HandleMark hm;
   Thread* THREAD = Thread::current();
-  tty->print_cr("Bootstrapping C1X....");
+  tty->print_cr("Bootstrapping graal....");
 
-  C1XCompiler* compiler = C1XCompiler::instance();
-  if (compiler == NULL) fatal("must use flag -XX:+UseC1X");
+  GraalCompiler* compiler = GraalCompiler::instance();
+  if (compiler == NULL) fatal("must use flag -XX:+UseGraal");
 
   jlong start = os::javaTimeMillis();
 
@@ -660,7 +660,7 @@
           if (current->is_Compiler_thread()) {
             CompilerThread* comp_thread = current->as_CompilerThread();
             if (comp_thread->is_compiling()) {
-              if (TraceC1X >= 4) {
+              if (Tracegraal >= 4) {
                 tty->print_cr("Compile queue empty, but following thread is still compiling:");
                 comp_thread->print();
               }
@@ -673,7 +673,7 @@
           break;
         }
       }
-      if (TraceC1X >= 5) {
+      if (Tracegraal >= 5) {
         _c1_method_queue->print();
       }
     }
@@ -707,8 +707,8 @@
   int c1_count = CompilationPolicy::policy()->compiler_count(CompLevel_simple);
   int c2_count = CompilationPolicy::policy()->compiler_count(CompLevel_full_optimization);
 #ifdef COMPILER1
-  if (UseC1X) {
-	  _compilers[0] = new C1XCompiler();
+  if (UseGraal) {
+	  _compilers[0] = new GraalCompiler();
   } else if (c1_count > 0) {
 	  _compilers[0] = new Compiler();
   }
@@ -1064,7 +1064,7 @@
 
     if (Thread::current()->is_Compiler_thread() && CompilerThread::current()->is_compiling() && !BackgroundCompilation) {
 
-      TRACE_C1X_1("Recursive compile %s!", method->name_and_sig_as_C_string());
+      TRACE_graal_1("Recursive compile %s!", method->name_and_sig_as_C_string());
       method->set_not_compilable();
       return;
     }
--- a/src/share/vm/graal/graalCodeInstaller.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalCodeInstaller.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -22,10 +22,10 @@
  */
 
 #include "precompiled.hpp"
-#include "c1x/c1x_Compiler.hpp"
-#include "c1x/c1x_CodeInstaller.hpp"
-#include "c1x/c1x_JavaAccess.hpp"
-#include "c1x/c1x_VmIds.hpp"
+#include "graal/graalCompiler.hpp"
+#include "graal/graalCodeInstaller.hpp"
+#include "graal/graalJavaAccess.hpp"
+#include "graal/graalVmIds.hpp"
 #include "c1/c1_Runtime1.hpp"
 #include "classfile/vmSymbols.hpp"
 #include "vmreg_x86.inline.hpp"
@@ -40,14 +40,14 @@
 const static int NUM_REGS = NUM_CPU_REGS + NUM_XMM_REGS;
 const static jlong NO_REF_MAP = 0x8000000000000000L;
 
-// convert c1x register indices (as used in oop maps) to hotspot registers
-VMReg get_hotspot_reg(jint c1x_reg) {
+// convert graal register indices (as used in oop maps) to hotspot registers
+VMReg get_hotspot_reg(jint graal_reg) {
 
-  assert(c1x_reg >= 0 && c1x_reg < NUM_REGS, "invalid register number");
-  if (c1x_reg < NUM_CPU_REGS) {
-    return CPU_REGS[c1x_reg]->as_VMReg();
+  assert(graal_reg >= 0 && graal_reg < NUM_REGS, "invalid register number");
+  if (graal_reg < NUM_CPU_REGS) {
+    return CPU_REGS[graal_reg]->as_VMReg();
   } else {
-    return XMM_REGS[c1x_reg - NUM_CPU_REGS]->as_VMReg();
+    return XMM_REGS[graal_reg - NUM_CPU_REGS]->as_VMReg();
   }
 }
 
@@ -105,13 +105,13 @@
   return map;
 }
 
 // TODO: finish this - c1x doesn't provide any scope values at the moment
 static ScopeValue* get_hotspot_value(oop value, int frame_size) {
   if (value == CiValue::IllegalValue()) {
     return new LocationValue(Location::new_stk_loc(Location::invalid, 0));
   }
 
-  BasicType type = C1XCompiler::kindToBasicType(CiKind::typeChar(CiValue::kind(value)));
+  BasicType type = GraalCompiler::kindToBasicType(CiKind::typeChar(CiValue::kind(value)));
   Location::Type locationType = Location::normal;
   if (type == T_OBJECT || type == T_ARRAY) locationType = Location::oop;
   if (value->is_a(CiRegisterValue::klass())) {
@@ -172,7 +172,7 @@
   }
 
   // (very) conservative estimate: each site needs a relocation
-  //CodeBuffer buffer("temp c1x method", _total_size, _sites->length() * relocInfo::length_limit);
+  //CodeBuffer buffer("temp graal method", _total_size, _sites->length() * relocInfo::length_limit);
   CodeBuffer buffer(CompilerThread::current()->get_buffer_blob());
   initialize_buffer(buffer);
   process_exception_handlers();
@@ -180,7 +180,7 @@
   int stack_slots = (_frame_size / HeapWordSize) + 2; // conversion to words, need to add two slots for ret address and frame pointer
   ThreadToNativeFromVM t((JavaThread*) Thread::current());
   _env->register_method(ciMethodObject, -1, &_offsets, _custom_stack_area_offset, &buffer, stack_slots, _debug_recorder->_oopmaps, &_exception_handler_table,
-      &_implicit_exception_table, C1XCompiler::instance(), _env->comp_level(), false, false);
+      &_implicit_exception_table, GraalCompiler::instance(), _env->comp_level(), false, false);
 
 }
 
@@ -198,7 +198,7 @@
 
   const char* cname = java_lang_String::as_utf8_string(_name);
   BufferBlob* blob = BufferBlob::create(strdup(cname), &buffer); // this is leaking strings... but only a limited number of stubs will be created
-  IF_TRACE_C1X_3 Disassembler::decode((CodeBlob*) blob);
+  IF_TRACE_graal_3 Disassembler::decode((CodeBlob*) blob);
   id = VmIds::addStub(blob->code_begin());
 }
 
@@ -260,16 +260,16 @@
     jint pc_offset = CiTargetMethod_Site::pcOffset(site);
 
     if (site->is_a(CiTargetMethod_Safepoint::klass())) {
-      TRACE_C1X_4("safepoint at %i", pc_offset);
+      TRACE_graal_4("safepoint at %i", pc_offset);
       site_Safepoint(buffer, pc_offset, site);
     } else if (site->is_a(CiTargetMethod_Call::klass())) {
-      TRACE_C1X_4("call at %i", pc_offset);
+      TRACE_graal_4("call at %i", pc_offset);
       site_Call(buffer, pc_offset, site);
     } else if (site->is_a(CiTargetMethod_DataPatch::klass())) {
-      TRACE_C1X_4("datapatch at %i", pc_offset);
+      TRACE_graal_4("datapatch at %i", pc_offset);
       site_DataPatch(buffer, pc_offset, site);
     } else if (site->is_a(CiTargetMethod_Mark::klass())) {
-      TRACE_C1X_4("mark at %i", pc_offset);
+      TRACE_graal_4("mark at %i", pc_offset);
       site_Mark(buffer, pc_offset, site);
     } else {
       fatal("unexpected Site subclass");
@@ -411,7 +411,7 @@
     reexecute = Interpreter::bytecode_should_reexecute(code);
   }
 
-  if (TraceC1X >= 2) {
+  if (Tracegraal >= 2) {
     tty->print_cr("Recording scope pc_offset=%d bci=%d frame=%d", pc_offset, bci, frame);
   }
 
@@ -427,7 +427,7 @@
     GrowableArray<ScopeValue*>* expressions = new GrowableArray<ScopeValue*> ();
     GrowableArray<MonitorValue*>* monitors = new GrowableArray<MonitorValue*> ();
 
-    if (TraceC1X >= 2) {
+    if (Tracegraal >= 2) {
       tty->print_cr("Scope at bci %d with %d values", bci, values->length());
       tty->print_cr("%d locals %d expressions, %d monitors", local_count, expression_count, monitor_count);
     }
@@ -493,31 +493,31 @@
   if (runtime_call != NULL) {
     NativeCall* call = nativeCall_at(_instructions->start() + pc_offset);
     if (runtime_call == CiRuntimeCall::Debug()) {
-      TRACE_C1X_3("CiRuntimeCall::Debug()");
+      TRACE_graal_3("CiRuntimeCall::Debug()");
     } else if (runtime_call == CiRuntimeCall::UnwindException()) {
-      call->set_destination(Runtime1::entry_for(Runtime1::c1x_unwind_exception_call_id));
+      call->set_destination(Runtime1::entry_for(Runtime1::graal_unwind_exception_call_id));
       _instructions->relocate(call->instruction_address(), runtime_call_Relocation::spec(), Assembler::call32_operand);
-      TRACE_C1X_3("CiRuntimeCall::UnwindException()");
+      TRACE_graal_3("CiRuntimeCall::UnwindException()");
     } else if (runtime_call == CiRuntimeCall::HandleException()) {
-      call->set_destination(Runtime1::entry_for(Runtime1::c1x_handle_exception_id));
+      call->set_destination(Runtime1::entry_for(Runtime1::graal_handle_exception_id));
       _instructions->relocate(call->instruction_address(), runtime_call_Relocation::spec(), Assembler::call32_operand);
-      TRACE_C1X_3("CiRuntimeCall::HandleException()");
+      TRACE_graal_3("CiRuntimeCall::HandleException()");
     } else if (runtime_call == CiRuntimeCall::JavaTimeMillis()) {
       call->set_destination((address)os::javaTimeMillis);
       _instructions->relocate(call->instruction_address(), runtime_call_Relocation::spec(), Assembler::call32_operand);
-      TRACE_C1X_3("CiRuntimeCall::JavaTimeMillis()");
+      TRACE_graal_3("CiRuntimeCall::JavaTimeMillis()");
     } else if (runtime_call == CiRuntimeCall::JavaTimeNanos()) {
       call->set_destination((address)os::javaTimeNanos);
       _instructions->relocate(call->instruction_address(), runtime_call_Relocation::spec(), Assembler::call32_operand);
-      TRACE_C1X_3("CiRuntimeCall::JavaTimeNanos()");
+      TRACE_graal_3("CiRuntimeCall::JavaTimeNanos()");
     } else if (runtime_call == CiRuntimeCall::ArithmeticFrem()) {
-      call->set_destination(Runtime1::entry_for(Runtime1::c1x_arithmetic_frem_id));
+      call->set_destination(Runtime1::entry_for(Runtime1::graal_arithmetic_frem_id));
       _instructions->relocate(call->instruction_address(), runtime_call_Relocation::spec(), Assembler::call32_operand);
-      TRACE_C1X_3("CiRuntimeCall::ArithmeticFrem()");
+      TRACE_graal_3("CiRuntimeCall::ArithmeticFrem()");
     } else if (runtime_call == CiRuntimeCall::ArithmeticDrem()) {
-      call->set_destination(Runtime1::entry_for(Runtime1::c1x_arithmetic_drem_id));
+      call->set_destination(Runtime1::entry_for(Runtime1::graal_arithmetic_drem_id));
       _instructions->relocate(call->instruction_address(), runtime_call_Relocation::spec(), Assembler::call32_operand);
-      TRACE_C1X_3("CiRuntimeCall::ArithmeticDrem()");
+      TRACE_graal_3("CiRuntimeCall::ArithmeticDrem()");
     } else if (runtime_call == CiRuntimeCall::RegisterFinalizer()) {
       call->set_destination(Runtime1::entry_for(Runtime1::register_finalizer_id));
       _instructions->relocate(call->instruction_address(), runtime_call_Relocation::spec(), Assembler::call32_operand);
@@ -538,7 +538,7 @@
       nativeJump_at((address)inst)->set_jump_destination(VmIds::getStub(global_stub));
     }
     _instructions->relocate((address)inst, runtime_call_Relocation::spec(), Assembler::call32_operand);
-    TRACE_C1X_3("relocating (stub)  at %016x", inst);
+    TRACE_graal_3("relocating (stub)  at %016x", inst);
   } else if (symbol != NULL) {
     fatal("symbol");
   } else { // method != NULL
@@ -551,7 +551,7 @@
 
     assert(debug_info != NULL, "debug info expected");
 
-    TRACE_C1X_3("method call");
+    TRACE_graal_3("method call");
     switch (_next_call_type) {
       case MARK_INVOKEVIRTUAL:
       case MARK_INVOKEINTERFACE: {
@@ -621,7 +621,7 @@
       *((jint*) operand) = (jint) disp;
 
       _instructions->relocate(instruction, section_word_Relocation::spec((address) dest, CodeBuffer::SECT_CONSTS), Assembler::disp32_operand);
-      TRACE_C1X_3("relocating (%c) at %016x/%016x with destination at %016x (%d)", typeChar, instruction, operand, dest, size);
+      TRACE_graal_3("relocating (%c) at %016x/%016x with destination at %016x (%d)", typeChar, instruction, operand, dest, size);
       break;
     }
     case 'a': {
@@ -632,7 +632,7 @@
         assert(!obj.is_null(), "");
         *((jobject*) operand) = JNIHandles::make_local(java_lang_Class::as_klassOop(HotSpotTypeResolved::javaMirror(obj)));
         _instructions->relocate(instruction, oop_Relocation::spec_for_immediate(), Assembler::imm_operand);
-        TRACE_C1X_3("relocating (HotSpotType) at %016x/%016x", instruction, operand);
+        TRACE_graal_3("relocating (HotSpotType) at %016x/%016x", instruction, operand);
       } else {
         jobject value;
         if (obj() == HotSpotProxy::DUMMY_CONSTANT_OBJ()) {
@@ -642,7 +642,7 @@
         }
         *((jobject*) operand) = value;
         _instructions->relocate(instruction, oop_Relocation::spec_for_immediate(), Assembler::imm_operand);
-        TRACE_C1X_3("relocating (oop constant) at %016x/%016x", instruction, operand);
+        TRACE_graal_3("relocating (oop constant) at %016x/%016x", instruction, operand);
       }
       break;
     }
@@ -105,13 +105,13 @@
 }
 
-// TODO: finish this - c1x doesn't provide any scope values at the moment
+// TODO: finish this - graal doesn't provide any scope values at the moment
 static ScopeValue* get_hotspot_value(oop value, int frame_size) {
   if (value == CiValue::IllegalValue()) {
--- a/src/share/vm/graal/graalJavaAccess.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalJavaAccess.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -22,7 +22,7 @@
  */
 
 #include "precompiled.hpp"
-#include "c1x/c1x_JavaAccess.hpp"
+#include "graal/graalJavaAccess.hpp"
 #include "runtime/jniHandles.hpp"
 #include "classfile/symbolTable.hpp"
 // This function is similar to javaClasses.cpp, it computes the field offset of a (static or instance) field.
@@ -50,7 +50,7 @@
   dest_offset = fd.offset();
 }
 
 // This piece of macro magic creates the contents of the c1x_compute_offsets method that initializes the field indices of all the access classes.
 
 #define START_CLASS(name) { klassOop k = SystemDictionary::name##_klass(); assert(k != NULL, "Could not find class " #name "");
 
@@ -65,7 +65,7 @@
 #define STATIC_OOP_FIELD(klass, name, signature) FIELD(klass, name, signature, true)
 
 
-void c1x_compute_offsets() {
+void graal_compute_offsets() {
   COMPILER_CLASSES_DO(START_CLASS, END_CLASS, CHAR_FIELD, INT_FIELD, BOOLEAN_FIELD, LONG_FIELD, OOP_FIELD, STATIC_OOP_FIELD)
 }
 
@@ -50,7 +50,7 @@
 }
 
-// This piece of macro magic creates the contents of the c1x_compute_offsets method that initializes the field indices of all the access classes.
+// This piece of macro magic creates the contents of the graal_compute_offsets method that initializes the field indices of all the access classes.
 
 #define START_CLASS(name) { klassOop k = SystemDictionary::name##_klass(); assert(k != NULL, "Could not find class " #name "");
--- a/src/share/vm/runtime/arguments.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/runtime/arguments.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -67,8 +67,8 @@
 int     Arguments::_num_jvm_flags               = 0;
 char**  Arguments::_jvm_args_array              = NULL;
 int     Arguments::_num_jvm_args                = 0;
-char**  Arguments::_c1x_args_array              = NULL;
-int     Arguments::_num_c1x_args                = 0;
+char**  Arguments::_graal_args_array              = NULL;
+int     Arguments::_num_graal_args                = 0;
 char*  Arguments::_java_command                 = NULL;
 SystemProperty* Arguments::_system_properties   = NULL;
 const char*  Arguments::_gc_log_filename        = NULL;
@@ -749,8 +749,8 @@
   add_string(&_jvm_flags_array, &_num_jvm_flags, arg);
 }
 
-void Arguments::add_c1x_arg(const char* arg) {
-  add_string(&_c1x_args_array, &_num_c1x_args, arg);
+void Arguments::add_graal_arg(const char* arg) {
+  add_string(&_graal_args_array, &_num_graal_args, arg);
 }
 
 // utility function to return a string that concatenates all
@@ -2668,8 +2668,8 @@
       if (PrintVMOptions) {
         tty->print("Running Graal VM... ");
       }
-      UseC1X = true;
-      BootstrapC1X = true;
+      UseGraal = true;
+      Bootstrapgraal = true;
       const int BUFFER_SIZE = 1024;
       char maxine_dir[BUFFER_SIZE];
       char graal_dir[BUFFER_SIZE];
@@ -2699,12 +2699,12 @@
       sprintf(temp, "%s/graal/com.oracle.max.graal.graphviz/bin", graal_dir);
       scp_p->add_prefix(temp);
       *scp_assembly_required_p = true;
-    } else if (match_option(option, "-C1X:", &tail)) { // -C1X:xxxx
-      // Option for the C1X compiler.
+    } else if (match_option(option, "-G:", &tail)) { // -graal:xxxx
+      // Option for the graal compiler.
       if (PrintVMOptions) {
-        tty->print_cr("C1X option %s", tail);
+        tty->print_cr("graal option %s", tail);
       }
-      Arguments::add_c1x_arg(tail);
+      Arguments::add_graal_arg(tail);
 
     // Unknown option
     } else if (is_bad_option(option, args->ignoreUnrecognized)) {
--- a/src/share/vm/runtime/arguments.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/runtime/arguments.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -228,9 +228,9 @@
   // an array containing all jvm arguments specified in the command line
   static char** _jvm_args_array;
   static int    _num_jvm_args;
-  // an array containing all c1x arguments specified in the command line
-  static char** _c1x_args_array;
-  static int    _num_c1x_args;
+  // an array containing all graal arguments specified in the command line
+  static char** _graal_args_array;
+  static int    _num_graal_args;
   // string containing all java command (class/jarfile name and app args)
   static char* _java_command;
 
@@ -369,7 +369,7 @@
   // methods to build strings from individual args
   static void build_jvm_args(const char* arg);
   static void build_jvm_flags(const char* arg);
-  static void add_c1x_arg(const char* arg);
+  static void add_graal_arg(const char* arg);
   static void add_string(char*** bldarray, int* count, const char* arg);
   static const char* build_resource_string(char** args, int count);
 
@@ -425,9 +425,9 @@
   // return a char* array containing all options
   static char** jvm_flags_array()          { return _jvm_flags_array; }
   static char** jvm_args_array()           { return _jvm_args_array; }
-  static char** c1x_args_array()           { return _c1x_args_array; }
+  static char** graal_args_array()           { return _graal_args_array; }
   static int num_jvm_flags()               { return _num_jvm_flags; }
-  static int num_c1x_args()               { return _num_c1x_args; }
+  static int num_graal_args()               { return _num_graal_args; }
   static int num_jvm_args()                { return _num_jvm_args; }
   // return the arguments passed to the Java application
   static const char* java_command()        { return _java_command; }
--- a/src/share/vm/runtime/thread.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/runtime/thread.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -833,8 +833,8 @@
 
  private:
 
-  // c1x needs some place to put the dimensions
-  jint c1x_multinewarray_storage[256];
+  // graal needs some place to put the dimensions
+  jint graal_multinewarray_storage[256];
 
   StackGuardState        _stack_guard_state;
 
@@ -1271,7 +1271,7 @@
   static ByteSize is_method_handle_return_offset() { return byte_offset_of(JavaThread, _is_method_handle_return); }
   static ByteSize stack_guard_state_offset()     { return byte_offset_of(JavaThread, _stack_guard_state   ); }
   static ByteSize suspend_flags_offset()         { return byte_offset_of(JavaThread, _suspend_flags       ); }
-  static ByteSize c1x_multinewarray_storage_offset() { return byte_offset_of(JavaThread, c1x_multinewarray_storage); }
+  static ByteSize graal_multinewarray_storage_offset() { return byte_offset_of(JavaThread, graal_multinewarray_storage); }
 
   static ByteSize do_not_unlock_if_synchronized_offset() { return byte_offset_of(JavaThread, _do_not_unlock_if_synchronized); }
   static ByteSize should_post_on_exceptions_flag_offset() {